==> mktcenter-service-2.0.2-20200813.074023-11-sources.jar: com/bizvane/mktcenterservice/models/vo/MktSignInRecordVo.java <==
package com.bizvane.mktcenterservice.models.vo;

import com.bizvane.mktcenterservice.models.po.MktActivityRecordPO;

import java.util.Date;

public class MktSignInRecordVo extends MktActivityRecordPO {

    // 会员所属门店
    private String storeName;
    // 会员所属门店id
    private Long sysStoreId;

    // 会员所属门店ids
    private String storeIds;

    // 会员姓名
    private String memberName;

    // 手机号
    private String phone;

    // 签到总次数
    private Integer totalNum;

    // 连续签到次数
    private Integer consecutiveNum;

    // 通用name查询条件
    private String searchName;

    private String beginDate;

    private String endDate;

    public String getStoreIds() {
        return storeIds;
    }

    public void setStoreIds(String storeIds) {
        this.storeIds = storeIds;
    }

    public String getStoreName() {
        return storeName;
    }

    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }

    public String getMemberName() {
        return memberName;
    }

    public void setMemberName(String memberName) {
        this.memberName = memberName;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public Integer getTotalNum() {
        return totalNum;
    }

    public void setTotalNum(Integer totalNum) {
        this.totalNum = totalNum;
    }

    public Integer getConsecutiveNum() {
        return consecutiveNum;
    }

    public void setConsecutiveNum(Integer consecutiveNum) {
        this.consecutiveNum = consecutiveNum;
    }

    public String getBeginDate() {
        return beginDate;
    }

    public void setBeginDate(String beginDate) {
        this.beginDate = beginDate;
    }

    public String getEndDate() {
        return endDate;
    }

    public void setEndDate(String endDate) {
        this.endDate = endDate;
    }

    public String getSearchName() {
        return searchName;
    }

    public void setSearchName(String searchName) {
        this.searchName = searchName;
    }

    @Override
    public Long getSysStoreId() {
        return sysStoreId;
    }

    @Override
    public void setSysStoreId(Long sysStoreId) {
        this.sysStoreId = sysStoreId;
    }
}

==> mktcenter-service-20240125-20240423.091204-2-sources.jar: com/bizvane/mktcenterservice/models/vo/MktSignInRecordVo.java <==
package com.bizvane.mktcenterservice.models.vo;

import com.bizvane.mktcenterservice.models.po.MktActivityRecordPO;
import io.swagger.annotations.ApiModelProperty;

import java.util.Date;

public class MktSignInRecordVo extends MktActivityRecordPO {

    // 会员所属门店
    private String storeName;
    // 会员所属门店id
    private Long sysStoreId;

    // 会员所属门店ids
    private String storeIds;

    // 会员姓名
    private String memberName;

    // 手机号
    private String phone;

    // 签到总次数
    private Integer totalNum;

    // 连续签到次数
    private Integer consecutiveNum;

    // 通用name查询条件
    private String searchName;

    private String beginDate;

    private String endDate;

    @ApiModelProperty(name = "activitySubjectType", value = "活动子类型 1-会员活动，2-群活动", example = "")
    private Integer activitySubjectType;

    @ApiModelProperty(name = "clientBaseInfoName", value = "群聊名称", example = "")
    private String clientBaseInfoName;

    public String getStoreIds() {
        return storeIds;
    }

    public void setStoreIds(String storeIds) {
        this.storeIds = storeIds;
    }

    public String getStoreName() {
        return storeName;
    }

    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }

    public String getMemberName() {
        return memberName;
    }

    public void setMemberName(String memberName) {
        this.memberName = memberName;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public Integer getTotalNum() {
        return totalNum;
    }

    public void setTotalNum(Integer totalNum) {
        this.totalNum = totalNum;
    }

    @Override
    public Integer getConsecutiveNum() {
        return consecutiveNum;
    }

    @Override
    public void setConsecutiveNum(Integer consecutiveNum) {
        this.consecutiveNum = consecutiveNum;
    }

    public String getBeginDate() {
        return beginDate;
    }

    public void setBeginDate(String beginDate) {
        this.beginDate = beginDate;
    }

    public String getEndDate() {
        return endDate;
    }

    public void setEndDate(String endDate) {
        this.endDate = endDate;
    }

    public String getSearchName() {
        return searchName;
    }

    public void setSearchName(String searchName) {
        this.searchName = searchName;
    }

    @Override
    public Long getSysStoreId() {
        return sysStoreId;
    }

    @Override
    public void setSysStoreId(Long sysStoreId) {
        this.sysStoreId = sysStoreId;
    }

    public Integer getActivitySubjectType() {
        return activitySubjectType;
    }

    public void setActivitySubjectType(Integer activitySubjectType) {
        this.activitySubjectType = activitySubjectType;
    }

    public String getClientBaseInfoName() {
        return clientBaseInfoName;
    }

    public void setClientBaseInfoName(String clientBaseInfoName) {
        this.clientBaseInfoName = clientBaseInfoName;
    }

}
